==> 1.0.0.tar.gz: lib/src/main/InitializedVariableDeclaration.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../sub_types/Identifiers.dart';
import '../main/Expression.dart';

/*
<initializedVariableDeclaration> ::=
<declaredIdentifier> ('=' <expression>)? (',' <initializedIdentifier>)*

See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
Page 14
*/
class InitializedVariableDeclaration extends ParserType {
  DeclaredIdentifier declaredIdentifier;
  Expression expression;
  List<InitializedIdentifier> initializedIdentifiers;

  InitializedVariableDeclaration(Lexer lexer) {
    // print ('Started InitializedVariableDeclaration');
    declaredIdentifier = DeclaredIdentifier(lexer);

    int snapShot = lexer.currentIndex;
    try {
      if (isType(lexer, TType.EQUALS)) {
        lexer.advance();
        expression = Expression(lexer);
      }
    }
    on WrongTokenType {
      lexer.setPos(snapShot);
    }

    initializedIdentifiers = [];
    try {
      snapShot = lexer.currentIndex;
      while (isType(lexer, TType.COMMA)) {
        snapShot = lexer.currentIndex;
        lexer.advance();
        initializedIdentifiers.add(InitializedIdentifier(lexer));
      }
    }
    on WrongTokenType {
      lexer.setPos(snapShot);
    }

    // print ('Finished InitializedVariableDeclaration');
  }

  String toString() {
    String rtn = '$declaredIdentifier' +
      (expression != null ? ' = $expression' : '');
    initializedIdentifiers.forEach((i) => rtn += ', $i');
    return rtn;
  }

}

==> 1.1.1.tar.gz: lib/src/main/InitializedVariableDeclaration.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import '../sub_types/Identifiers.dart';
import '../main/Expression.dart';

/// <initializedVariableDeclaration> ::=
/// <declaredIdentifier> ('=' <expression>)? (',' <initializedIdentifier>)*
///
/// See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
/// Page 14
class InitializedVariableDeclaration extends ParserType {
  DeclaredIdentifier declaredIdentifier;
  Expression expression;
  List<InitializedIdentifier> initializedIdentifiers;

  InitializedVariableDeclaration(Lexer lexer) {
    // print ('Started InitializedVariableDeclaration');
    declaredIdentifier = DeclaredIdentifier(lexer);

    int snapShot = lexer.currentIndex;
    try {
      if (isType(lexer, TType.EQUALS)) {
        lexer.advance();
        expression = Expression(lexer);
      }
    } on WrongTokenType {
      lexer.setPos(snapShot);
    }

    initializedIdentifiers = [];
    try {
      snapShot = lexer.currentIndex;
      while (isType(lexer, TType.COMMA)) {
        snapShot = lexer.currentIndex;
        lexer.advance();
        initializedIdentifiers.add(InitializedIdentifier(lexer));
      }
    } on WrongTokenType {
      lexer.setPos(snapShot);
    }

    // print ('Finished InitializedVariableDeclaration');
  }

  String toString() {
    String rtn =
        '$declaredIdentifier' + (expression != null ? ' = $expression' : '');
    initializedIdentifiers.forEach((i) => rtn += ', $i');
    return rtn;
  }
}
